@@ -201,29 +201,29 @@ static CategoriesTreeItem user_interface [] =
 	{_("MDI"), NULL, MDI_SETTINGS},
 #endif
 
-	NULL
+	{ NULL }
 };
 
 static CategoriesTreeItem editor_behavior [] =
 {
 	{_("Font & Colors"), NULL, FONT_COLORS_SETTINGS},
-	
- 	{_("Save"), NULL, SAVE_SETTINGS },
-/*
+
 	{_("Tabs"), NULL, TABS_SETTINGS},
-*/	
-	{_("Undo"), NULL, UNDO_SETTINGS},
 	{_("Wrap mode"), NULL, WRAP_MODE_SETTINGS},
 	{_("Line numbers"), NULL , LINE_NUMBERS_SETTINGS},
+	
+ 	{_("Save"), NULL, SAVE_SETTINGS },
+	{_("Undo"), NULL, UNDO_SETTINGS},
 
-	NULL
+
+	{ NULL }
 };
 
 static CategoriesTreeItem print [] =
 {
 	{_("Page"), NULL, PRINT_SETTINGS},
 
-	NULL
+	{ NULL }
 };
 
 static CategoriesTreeItem toplevel [] =
@@ -231,29 +231,33 @@ static CategoriesTreeItem toplevel [] =
 	{_("Editor"), editor_behavior, LOGO},
 	{_("Print"), print, LOGO},
 	{_("User interface"), user_interface, LOGO},
-	NULL
+	{ NULL }
 };
 
-GtkType
+GType
 gedit_preferences_dialog_get_type (void)
 {
-	static GtkType dialog_type = 0;
+	static GType dialog_type = 0;
 
 	if (!dialog_type)
     	{
-      		static const GtkTypeInfo dialog_info =
+      		static const GTypeInfo dialog_info =
       		{
-			"GeditPreferencesDialog",
-			sizeof (GeditPreferencesDialog),
 			sizeof (GeditPreferencesDialogClass),
-			(GtkClassInitFunc) gedit_preferences_dialog_class_init,
-			(GtkObjectInitFunc) gedit_preferences_dialog_init,
-			/* reserved_1 */ NULL,
-        		/* reserved_2 */ NULL,
-        		(GtkClassInitFunc) NULL,
+        		NULL,		/* base_init */
+        		NULL,		/* base_finalize */
+        		(GClassInitFunc) gedit_preferences_dialog_class_init,
+        		NULL,           /* class_finalize */
+        		NULL,           /* class_data */
+        		sizeof (GeditPreferencesDialog),
+        		0,              /* n_preallocs */
+        		(GInstanceInitFunc) gedit_preferences_dialog_init
       		};
 
-     		dialog_type = gtk_type_unique (GTK_TYPE_DIALOG, &dialog_info);
+     		dialog_type = g_type_register_static (GTK_TYPE_DIALOG,
+						      "GeditPreferencesDialog",
+						      &dialog_info, 
+						      0);
     	}
 
 	return dialog_type;
@@ -594,7 +598,7 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 				GTK_TOGGLE_BUTTON (dlg->priv->toolbar_icon_text_radiobutton), TRUE);
 			break;
 
-		dafult:
+		default:
 			g_return_val_if_fail (FALSE, FALSE);
 	}
 	
@@ -733,8 +737,7 @@ gedit_preferences_dialog_default_font_colors_checkbutton_toggled (GtkToggleButto
 static gboolean 
 gedit_preferences_dialog_setup_font_and_colors_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
-	GeditView* active_view = NULL;
-	GtkWidget* font_label;
+	GtkWidget *font_label;
 	
 	gedit_debug (DEBUG_PREFS, "");
 	
@@ -814,6 +817,8 @@ gedit_preferences_dialog_setup_font_and_colors_page (GeditPreferencesDialog *dlg
 			(dlg->priv->default_font_checkbutton), gedit_settings->use_default_font);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
 			(dlg->priv->default_colors_checkbutton), gedit_settings->use_default_colors);
+
+	return TRUE;
 }
 
 static void
@@ -851,6 +856,8 @@ gedit_preferences_dialog_setup_undo_page (GeditPreferencesDialog *dlg, GladeXML
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->undo_checkbutton), 
 			gedit_settings->undo_levels > 0);
+
+	return TRUE;
 }
 
 
@@ -865,6 +872,8 @@ gedit_preferences_dialog_setup_tabs_page (GeditPreferencesDialog *dlg, GladeXML
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (dlg->priv->tabs_width_spinbutton),
 					   (guint) gedit_settings->tab_size);
+
+	return TRUE;
 }
 
 static gboolean 
@@ -887,6 +896,8 @@ gedit_preferences_dialog_setup_logo_page (GeditPreferencesDialog *dlg, GladeXML
 	g_object_set_property (G_OBJECT (logo), "file" , &value);
 
 	g_value_unset (&value);
+
+	return TRUE;
 }
 
 static gboolean 
@@ -1036,6 +1047,8 @@ gedit_preferences_dialog_setup_page_page (GeditPreferencesDialog *dlg, GladeXML
 	
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->line_numbers_checkbutton),
 				gedit_settings->print_line_numbers > 0);
+
+	return TRUE;
 }
 
 static gboolean 
@@ -1050,13 +1063,14 @@ gedit_preferences_dialog_setup_line_numbers_page (GeditPreferencesDialog *dlg, G
 	
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->display_line_numbers_checkbutton),
 				gedit_settings->show_line_numbers);
+
+	return TRUE;
 }
 
 gboolean 
 gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 {
 	GeditPreferences old_prefs;
-	gint index;
 	const gchar* font;
 	guint16 dummy;
 
@@ -1219,7 +1233,11 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 
 	gedit_settings->show_line_numbers = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-					      dlg->priv->display_line_numbers_checkbutton));	
+					      dlg->priv->display_line_numbers_checkbutton));
+
+	/* Tabs page */	
+	gedit_settings->tab_size =
+		gtk_spin_button_get_value (GTK_SPIN_BUTTON (dlg->priv->tabs_width_spinbutton));
 
 	return TRUE;
 	
