@@ -41,7 +41,8 @@
 #include "gedit-debug.h"
 #include "gedit-utils.h"
 #include "gedit-undo-manager.h"
-  
+
+#include "gedit-marshal.h"
 
 #define NOT_EDITABLE_TAG_NAME "not_editable_tag"
 
@@ -173,7 +174,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, name_changed),
 			      NULL, NULL,
-			      gtk_marshal_VOID__VOID,
+			      gedit_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
 	
@@ -183,7 +184,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, loaded),
 			      NULL, NULL,
-			      gtk_marshal_VOID__VOID,
+			      gedit_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
 	
@@ -193,7 +194,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, saved),
 			      NULL, NULL,
-			      gtk_marshal_VOID__VOID,
+			      gedit_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
 
@@ -203,7 +204,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, readonly_changed),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -214,7 +215,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, can_undo),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -225,7 +226,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, can_redo),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -485,13 +486,14 @@ gedit_document_get_short_name (const GeditDocument* doc)
 }
 
 GQuark 
-gedit_document_io_error_quark()
+gedit_document_io_error_quark (void)
 {
-  static GQuark quark;
-  if (!quark)
-    quark = g_quark_from_static_string ("gedit_io_load_error");
+	static GQuark quark;
+	
+	if (!quark)
+		quark = g_quark_from_static_string ("gedit_io_load_error");
 
-  return quark;
+	return quark;
 }
 
 static gboolean
@@ -836,6 +838,27 @@ gedit_document_save_as (GeditDocument* doc, const gchar *uri, GError **error)
 	return ret;
 }
 
+gboolean	
+gedit_document_save_a_copy_as (GeditDocument* doc, const gchar *uri, GError **error)
+{
+	gboolean m;
+	gboolean ret;
+
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_val_if_fail (doc != NULL, FALSE);
+	g_return_val_if_fail (doc->priv != NULL, FALSE);
+	g_return_val_if_fail (uri != NULL, FALSE);
+	
+	m = gedit_document_get_modified (doc);
+
+	ret = gedit_document_save_as_real (doc, uri, FALSE, error);
+	
+	gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc), m);	 
+
+	return ret;
+}
+
 static gboolean	
 gedit_document_save_as_real (GeditDocument* doc, const gchar *uri,
 	       gboolean create_backup_copy, GError **error)
@@ -1533,3 +1556,32 @@ gedit_document_get_line_at_offset (const GeditDocument *doc, guint offset)
 	return gtk_text_iter_get_line (&iter);
 }
 
+gint gedit_document_get_cursor (GeditDocument *doc)
+{
+	GtkTextIter iter;
+	
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
+
+	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (doc),			
+                                    &iter,
+                                    gtk_text_buffer_get_mark (GTK_TEXT_BUFFER (doc),
+					                      "insert"));
+
+	return gtk_text_iter_get_offset (&iter); 
+}
+
+void
+gedit_document_set_cursor (GeditDocument *doc, gint cursor)
+{
+	GtkTextIter iter;
+	
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+	
+	/* Place the cursor at the requested position */
+	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &iter, cursor);
+	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
+}
